<?php

/**
 * CLTracker_Cookie is a simple API to get and set cookie in client side
 * 
 * @since 1.0.0
 * 
 */

class CLTracker_Cookie {

	/**
	 * Sets cookie in client side
	 * 
	 * @param string $key Name of the cookie
	 * @param string $value Value of the cookie
	 * 
	 * @since 1.0.0
	 * 
	 */
	public static function set_cookie( $key, $value ) {
		@ setrawcookie( 'cltracker_' . $key . '_' . COOKIEHASH, rawurlencode($value), time() + DAY_IN_SECONDS, COOKIEPATH, COOKIE_DOMAIN );
		$_COOKIE[ 'cltracker_' . $key . '_' . COOKIEHASH ] = $value;
	}

	/**
	 * Gets cookie value from the client side
	 * 
	 * @param string $key Name of the cookie
	 * @param string $value Value of the cookie default value
	 * 
	 * @since 1.0.0
	 * 
	 */
	public static function get_cookie( $key, $value = '' ) {

		if ( ! empty( $value ) ) {
			return isset( $_COOKIE[ 'cltracker_' . $key . '_' . COOKIEHASH ] ) && $value === $_COOKIE[ 'cltracker_' . $key . '_' . COOKIEHASH ];
		} else if ( isset( $_COOKIE[ 'cltracker_' . $key . '_' . COOKIEHASH ] ) ) {
			return $_COOKIE[ 'cltracker_' . $key . '_' . COOKIEHASH ];
		} else {
			return false;
		}
	}

	/**
	 * Gets cookie value from the client side where name start with 
	 * 
	 * @param string $key Name of the cookie start with
	 * 
	 * @since 1.0.0
	 * 
	 */
	public static function get_cookies_start_with( $key ) {
		
		$set = false;
		$cookies = array();
		$cookie_name = "cltracker_" . $key . '_';
		foreach ($_COOKIE as $name => $value) {
			if (stripos($name, $cookie_name) === 0) {
				$cookies[] = $_COOKIE[$name];
				$set = true;
			}
		}
		
		print_r($set);
		
		if (!$set) {
			return false;
		}

		return $cookies;
	}

	/**
	 * Deletes cookie from the client
	 * 
	 * @param string $key Name of the cookie
	 * 
	 * @since 1.0.0
	 * 
	 */
	public static function unset_cookie( $key = '' ) {

		if ( isset( $_POST['key'] ) ) {
			$key = sanitize_text_field( $_POST['key'] );
		}

		@ setcookie( 'cltracker_' . $key . '_' . COOKIEHASH, '', time() - DAY_IN_SECONDS, COOKIEPATH, COOKIE_DOMAIN );
		unset( $_COOKIE[ 'cltracker_' . $key . '_' . COOKIEHASH ] );

		wp_send_json_success( $key );
	}

}

add_action( 'wp_ajax_cltracker_unset_cookie'       , array( 'CLTracker_Cookie', 'unset_cookie' ) );
add_action( 'wp_ajax_nopriv_cltracker_unset_cookie', array( 'CLTracker_Cookie', 'unset_cookie' ) );